#
# This is a Shiny web application. You can run the application by clicking
# the 'Run App' button above.
#
# Find out more about building applications with Shiny here:
#
#    http://shiny.rstudio.com/
#


library(shiny)
library(shinybusy)
library(shinyWidgets)
library(tidyverse)
library(lubridate)
library(ggpubr)
library(reshape2)
library(gt)
library(leaflet)
library(sf)


#setwd("C:/Users/juliegil/Dropbox (University of Michigan)/MICOM/WCHD/Firearm_Locks_Dashboard/map_view_ex")
zipcode_boundaries <- "data/cb_2018_us_zcta510_500k/cb_2018_us_zcta510_500k.shp"

# convert it to shape file system (R)
zip_shp <- st_read(zipcode_boundaries, stringsAsFactors=FALSE)
zip_shp <- filter(zip_shp, substr(GEOID10, 1, 2) == "48")
zip_shp_ll <- st_transform(zip_shp, "+proj=longlat +ellps=WGS84 +datum=WGS84")
zip_shp_ll <- st_as_sf(zip_shp_ll)
zip_shp_ll <- st_cast(zip_shp_ll, to = c("POLYGON"))


# Define UI for application 
ui <- fluidPage(
  tags$head(tags$link(rel = "stylesheet", type = "text/css", href = "style-page.css")),
  navbarPage(div(img(src="logo_screenshot.png", height = 45, width= 55), ""), 
              id = "original",
              tabPanel("Home", id = "home_page",
                       titlePanel(" "),
                       
                       div(class="col-xs-12 col-sm-12 col-md-9 col-lg-9 col-xl-9 col-xxl-9",
                           leafletOutput(outputId = "overview_map")
                       ), 
                       div(class="col-xs-12 col-sm-12 col-md-3 col-lg-3 col-xl-3 col-xxl-3",
                           #dateRangeInput("home_daterange", h6(strong("Date Range:")),
                          #                start = Sys.Date() %m-% months(4),
                           #               end = Sys.Date()),
                           style="text-align:left;color:black;background-color:#DADFE7;padding:15px;border-radius:0px"),
               
                       br()
                       
              ),
              tabPanel("Statistical Analysis", id = "transportation_page",
                       titlePanel(" "),
                       
                       div(class="col-xs-12 col-sm-12 col-md-9 col-lg-9 col-xl-9 col-xxl-9",
                           #plotOutput("transportation_heatmap", height = 600)
                       ), 
                       div(class="col-xs-12 col-sm-12 col-md-3 col-lg-3 col-xl-3 col-xxl-3",
                       #     dateRangeInput("transport_daterange", h6(strong("Date Range:")),
                       #                    start = Sys.Date() %m-% months(4),
                       #                    end = Sys.Date()),
                       #     style="text-align:left;color:black;background-color:#DADFE7;padding:15px;border-radius:0px"),
                       # 
                       # br(), 
                       # br(),
                       # 
                       # div(class="col-xs-12 col-sm-12 col-md-6 col-lg-6 col-xl-6 col-xxl-6",
                       #     plotOutput("transportation_rides")
                       # ),
                       # div(class="col-xs-12 col-sm-12 col-md-6 col-lg-6 col-xl-6 col-xxl-6",
                       #     plotOutput("transportation_rides_per_month")
                       # ),
                       # br(),
                       # div(class="col-xs-12 col-sm-12 col-md-12 col-lg-12 col-xl-12 col-xxl-12",
                       #     
                       #     style="text-align:left;color:black;background-color:#FFFFFF;padding:15px;border-radius:0px"),
                       # 
                       # br(),
                       # div(class="col-xs-12 col-sm-12 col-md-3 col-lg-3 col-xl-3 col-xxl-3",
                       #     radioButtons("transport_scatter_color", h6(strong("Color Rides Over:")),
                       #                  choices = c("$40", "$50", "$100", "None"), 
                       #                  selected = "None"),
                           style="text-align:left;color:black;background-color:#DADFE7;padding:15px;border-radius:0px"),
                       
                       div(class="col-xs-12 col-sm-12 col-md-9 col-lg-9 col-xl-9 col-xxl-9",
                           #plotOutput("transportation_ride_cost")
                       ),
                       
                       
                       br()
                       
              ), 
              tabPanel("Data Downloads", id = "tis_page",
                       titlePanel(" "),
                       
                       
                       div(class="col-xs-12 col-sm-12 col-md-9 col-lg-9 col-xl-9 col-xxl-9",
                           #plotOutput("tis_bar_by_person", height = 800)
                       ), 
                       div(class="col-xs-12 col-sm-12 col-md-3 col-lg-3 col-xl-3 col-xxl-3",
                           # dateRangeInput("tis_daterange", h6(strong("Date Range:")),
                           #                start = Sys.Date() %m-% months(4),
                           #                end = Sys.Date()),
                           # checkboxGroupInput("tis_category", 
                           #                    h6(strong("Categories:")), 
                           #                    choices = unique(tis$Expense),
                           #                    selected = unique(tis$Expense)),
                           style="text-align:left;color:black;background-color:#DADFE7;padding:15px;border-radius:0px"),
                       
                       
                       
                       br(),
                       br(),
                       br()
              )
  )
)

# Define server logic required to draw a histogram
server <- function(input, output) {

  output$overview_map <- renderLeaflet({
    
    leaflet() %>%
      addTiles() %>% setView(lng = -83.8473,
                         lat = 42.3076,
                         zoom = 10) %>%
      addPolygons(data = zip_shp_ll$geometry,
                         color = "#000000", # you need to use hex colors
                         fillOpacity = 0,
                         weight = 1,
                         smoothFactor = 0.2)
    
  })
  
  
}

# Run the application 
shinyApp(ui = ui, server = server)
